@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2001-2014 Mathew A. Nelson and Robocode contributors
+ * Copyright (c) 2001-2018 Mathew A. Nelson and Robocode contributors
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -31,7 +31,8 @@ public class TestConstructorReflectionAttack extends RobocodeTestBed {
 
 		final String out = event.getTurnSnapshot().getRobots()[0].getOutputStreamSnapshot();
 
-		if (out.contains("access denied (java.lang.reflect.ReflectPermission")) {
+		if (out.contains("access denied (java.lang.reflect.ReflectPermission")
+				|| out.contains("access denied (\"java.lang.reflect.ReflectPermission\"")) {
 			messagedAccessDenied = true;
 		}
 	}
